==> ij-rubik-1.89.0.tgz: package/src/vendors/hotjar/paths.js <==
const HOTJAR_PATHS = {
  es: [
    '/',
    '/home/index.xhtml',
    '/oferta.empleo',
    '/jobsearch/search-results/list.xhtml',
    '/pfw/ca/contenido.jsp',
    '/external-offer',
    '/candidate/application/index.xhtml',
    '/candidate/cv/cv-edit/edit.xhtml',
    '/candidate/cv/view/index.xhtml',
    '/candidate/external-offer',
    '/candidate/external-offer.xhtml',
    '/candidate/my-infojobs.xhtml',
    '/candidate/saved-searches/list.xhtml',
    '/candidate/create-profile/validation.xhtml',
    '/candidate/applications/list.xhtml',
    '/candidate/applications/list-events.xhtml',
    '/home-employer-responsive/index.xhtml',
    '/employer/manage/offers/management-view.xhtml',
    '/employer/offer/cw/insert-upgrade.xhtml',
    '/employer/menu/my-menu.xhtml',
    '/employer/profile/profile-edit/edit.xhtml',
    '/employer/menu/web/cw.xhtml',
    '/employer/menu/ps/ps.xhtml',
    '/employer/buys/payment-gateway/view.xhtml',
    '/employer/buys/finish-order.xhtml',
    '/employer/cv-search/employer-cv-search-results.xhtml',
    '/employer/kq/kq/management-view.xhtml',
    '/employer/cv-search/index.xhtml',
    '/employer/offer/cw/insert-requirements.xhtml',
    '/employer-application-list.xhtml',
    '/employer/contract/offers-packs.xhtml',
    '/employer/contract/offers-packs-galactico.xhtml',
    '/employer/profile/reviews/index.xhtml',
    '/employer/stats/stats-offers/offers.xhtml'
  ],
  it: []
}

const getPaths = portal => {
  return HOTJAR_PATHS[portal]
}

export default getPaths

==> ij-rubik-1.110.0.tgz: package/src/vendors/hotjar/paths.js <==
const HOTJAR_PATHS = {
  es: [
    '/',
    '/home/index.xhtml',
    '/oferta.empleo',
    '/jobsearch/search-results/list.xhtml',
    '/pfw/ca/contenido.jsp',
    '/external-offer',
    '/candidate/application/index.xhtml',
    '/candidate/cv/cv-edit/edit.xhtml',
    '/candidate/cv/view/index.xhtml',
    '/candidate/external-offer',
    '/candidate/external-offer.xhtml',
    '/candidate/my-infojobs.xhtml',
    '/candidate/saved-searches/list.xhtml',
    '/candidate/create-profile/validation.xhtml',
    '/candidate/applications/list.xhtml',
    '/candidate/applications/list-events.xhtml',
    '/home-employer-responsive/index.xhtml',
    '/employer/manage/offers/management-view.xhtml',
    '/employer/offer/cw/insert-upgrade.xhtml',
    '/employer/menu/my-menu.xhtml',
    '/employer/profile/profile-edit/edit.xhtml',
    '/employer/menu/web/cw.xhtml',
    '/employer/menu/ps/ps.xhtml',
    '/employer/buys/payment-gateway/view.xhtml',
    '/employer/buys/finish-order.xhtml',
    '/employer/cv-search/employer-cv-search-results.xhtml',
    '/employer/kq/kq/management-view.xhtml',
    '/employer/cv-search/index.xhtml',
    '/employer/offer/cw/insert-requirements.xhtml',
    '/employer-application-list.xhtml',
    '/employer/contract/offers-packs.xhtml',
    '/employer/contract/offers-packs-galactico.xhtml',
    '/employer/profile/reviews/index.xhtml',
    '/employer/stats/stats-offers/offers.xhtml',
    '/landing_publica_gratis_varios_portales'
  ],
  it: []
}

const getPaths = portal => {
  return HOTJAR_PATHS[portal]
}

export default getPaths
